@@ -337,5 +337,7 @@ int mk_sched_send_signal(struct mk_server *server, uint64_t val);
 int mk_sched_workers_join(struct mk_server *server);
 int mk_sched_threads_purge(struct mk_sched_worker *sched);
 int mk_sched_threads_destroy_all(struct mk_sched_worker *sched);
+int mk_sched_threads_destroy_conn(struct mk_sched_worker *sched,
+                                  struct mk_sched_conn *conn);
 
 #endif
